@@ -21,21 +21,16 @@
 */
 #include "knewpassworddialog.h"
 
-#include <QApplication>
-#include <QProgressBar>
 #include <QPushButton>
-#include <QRegExp>
-#include <QSize>
 #include <QString>
 #include <QStyleOption>
-#include <QLineEdit>
 #include <QMessageBox>
 
 #include <ktitlewidget.h>
 
 #include "ui_knewpassworddialog.h"
 
-class KNewPasswordDialog::KNewPasswordDialogPrivate
+class Q_DECL_HIDDEN KNewPasswordDialog::KNewPasswordDialogPrivate
 {
 public:
     KNewPasswordDialogPrivate(KNewPasswordDialog *parent)
@@ -49,6 +44,7 @@ public:
     KNewPasswordDialog *q;
 
     QString pass;
+    QIcon icon;
 
     Ui::KNewPasswordDialog ui;
 };
@@ -56,11 +52,8 @@ public:
 void KNewPasswordDialog::KNewPasswordDialogPrivate::init()
 {
     ui.setupUi(q);
+    q->setIcon(QIcon::fromTheme(QStringLiteral("dialog-password")));
 
-    QStyleOption option;
-    option.initFrom(q);
-    const int iconSize = q->style()->pixelMetric(QStyle::PM_MessageBoxIconSize, &option, q);
-    ui.labelIcon->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-password")).pixmap(iconSize, iconSize));
     ui.statusMsgWidget->hide();
 
     connect(ui.pwdWidget, SIGNAL(passwordStatusChanged()), q, SLOT(_k_passwordStatusChanged()));
@@ -73,20 +66,20 @@ void KNewPasswordDialog::KNewPasswordDialogPrivate::_k_passwordStatusChanged()
         ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
         //~ singular Password must be at least %n character long
         //~ plural Password must be at least %n characters long
-        showMessageWidget(tr("Password must be at least %n character(s) long", "", ui.pwdWidget->minimumPasswordLength()), KMessageWidget::Error);
+        showMessageWidget(tr("Password must be at least %n character(s) long.", "@info", ui.pwdWidget->minimumPasswordLength()), KMessageWidget::Error);
         break;
     case KNewPasswordWidget::EmptyPasswordNotAllowed:
         ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
-        showMessageWidget(tr("Password is empty"), KMessageWidget::Warning);
+        showMessageWidget(tr("Password is empty.", "@info"), KMessageWidget::Warning);
         break;
     case KNewPasswordWidget::PasswordNotVerified:
         ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
-        showMessageWidget(tr("Passwords do not match"), KMessageWidget::Warning);
+        showMessageWidget(tr("Passwords do not match.", "@info"), KMessageWidget::Warning);
         break;
     case KNewPasswordWidget::WeakPassword:
     case KNewPasswordWidget::StrongPassword:
         ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
-        showMessageWidget(tr("Passwords match"), KMessageWidget::Positive);
+        showMessageWidget(tr("Passwords match.", "@info"), KMessageWidget::Positive);
         break;
     }
 }
@@ -124,6 +117,22 @@ QString KNewPasswordDialog::prompt() const
     return d->ui.labelPrompt->text();
 }
 
+void KNewPasswordDialog::setIcon(const QIcon &icon)
+{
+    d->icon = icon;
+    QStyleOption option;
+    option.initFrom(this);
+    const int iconSize = style()->pixelMetric(QStyle::PM_MessageBoxIconSize, &option, this);
+    d->ui.labelIcon->setPixmap(icon.pixmap(iconSize, iconSize));
+    d->ui.labelIcon->setFixedSize(d->ui.labelIcon->sizeHint());
+}
+
+QIcon KNewPasswordDialog::icon() const
+{
+    return d->icon;
+}
+
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 63)
 void KNewPasswordDialog::setPixmap(const QPixmap &pixmap)
 {
     d->ui.labelIcon->setPixmap(pixmap);
@@ -132,8 +141,13 @@ void KNewPasswordDialog::setPixmap(const QPixmap &pixmap)
 
 QPixmap KNewPasswordDialog::pixmap() const
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    return d->ui.labelIcon->pixmap(Qt::ReturnByValue);
+#else
     return *d->ui.labelIcon->pixmap();
+#endif
 }
+#endif
 
 bool KNewPasswordDialog::checkAndGetPassword(QString *pwd)
 {
@@ -141,7 +155,7 @@ bool KNewPasswordDialog::checkAndGetPassword(QString *pwd)
 
     if (d->ui.pwdWidget->passwordStatus() == KNewPasswordWidget::WeakPassword) {
         QMessageBox::StandardButton selectedButton = QMessageBox::warning(this,
-                tr("Low Password Strength"),
+                tr("Low Password Strength", "@title:window"),
                 tr("The password you have entered has a low strength. "
                    "To improve the strength of "
                    "the password, try:\n"
