@@ -29,6 +29,8 @@ class KTimeComboBoxPrivate;
 
 /**
  * @class KTimeComboBox ktimecombobox.h KTimeComboBox
+ *
+ * @short A combobox for times.
  */
 class KWIDGETSADDONS_EXPORT KTimeComboBox : public QComboBox
 {
@@ -46,6 +48,7 @@ public:
      * Options provided by the widget
      * @see options
      * @see setOptions
+     * @see Options
      */
     enum Option {
         EditTime         = 0x0001,  /**< Allow the user to manually edit the time in the combo line edit */
@@ -53,6 +56,9 @@ public:
         ForceTime        = 0x0004,  /**< Any set or entered time will be forced to one of the drop-down times */
         WarnOnInvalid    = 0x0008   /**< Show a warning box on focus out if the user enters an invalid time */
     };
+    /**
+     * Stores a combination of #Option values.
+     */
     Q_DECLARE_FLAGS(Options, Option)
     Q_FLAG(Options)
 
@@ -64,7 +70,7 @@ public:
     /**
      * Destroy the widget
      */
-    virtual ~KTimeComboBox();
+    ~KTimeComboBox() override;
 
     /**
      * Return the currently selected time
@@ -78,16 +84,18 @@ public:
      *
      * If the user input is null then it is not valid
      *
-     * @see isNull()
      * @return if the current user input is valid
+     *
+     * @see isNull()
      */
     bool isValid() const;
 
     /**
      * Return if the current user input is null
      *
-     * @see isValid()
      * @return if the current user input is null
+     *
+     * @see isValid()
      */
     bool isNull() const;
 
@@ -156,18 +164,20 @@ public:
      *
      * Returns -1 if not set.
      *
-     * @see setTimeListInterval()
      * @return the select time list interval in minutes
+     *
+     * @see setTimeListInterval()
      */
     int timeListInterval() const;
 
     /**
      * Return the list of times able to be selected in the drop-down.
      *
+     * @return the select time list
+     *
      * @see setTimeList()
      * @see timeListInterval()
      * @see setTimeListInterval()
-     * @return the select time list
      */
     QList<QTime> timeList() const;
 
@@ -235,12 +245,13 @@ public Q_SLOTS:
      * If the time is invalid, or greater than current maximum,
      * then the minimum will not be set.
      *
+     * @param minTime the minimum time
+     * @param minWarnMsg the minimum warning message
+     *
      * @see minimumTime()
      * @see maximumTime()
      * @see setMaximumTime()
      * @see setTimeRange()
-     * @param minTime the minimum time
-     * @param minWarnMsg the minimum warning message
      */
     void setMinimumTime(const QTime &minTime, const QString &minWarnMsg = QString());
 
@@ -250,12 +261,13 @@ public Q_SLOTS:
      * If the time is invalid, or less than current minimum,
      * then the maximum will not be set.
      *
+     * @param maxTime the maximum time
+     * @param maxWarnMsg the maximum warning message
+     *
      * @see minimumTime()
      * @see maximumTime()
      * @see setMaximumTime()
      * @see setTimeRange()
-     * @param maxTime the maximum time
-     * @param maxWarnMsg the maximum warning message
      */
     void setMaximumTime(const QTime &maxTime, const QString &maxWarnMsg = QString());
 
@@ -275,8 +287,9 @@ public Q_SLOTS:
      * Setting the time list interval will override any time list previously set
      * via setTimeList().
      *
-     * @see timeListInterval()
      * @param minutes the time list interval to display
+     *
+     * @see timeListInterval()
      */
     void setTimeListInterval(int minutes);
 
@@ -292,10 +305,11 @@ public Q_SLOTS:
      * The minimum and maximum time will automatically be set to the earliest
      * and latest value in the list.
      *
-     * @see timeList()
      * @param timeList the list of times able to be selected
      * @param minWarnMsg the minimum warning message
      * @param maxWarnMsg the maximum warning message
+     *
+     * @see timeList()
      */
     void setTimeList(QList<QTime> timeList,
                      const QString &minWarnMsg = QString(),
@@ -303,15 +317,15 @@ public Q_SLOTS:
 
 protected:
 
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
-    void showPopup() Q_DECL_OVERRIDE;
-    void hidePopup() Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
-    void focusInEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
-    void focusOutEvent(QFocusEvent *event) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
+    void showPopup() override;
+    void hidePopup() override;
+    void mousePressEvent(QMouseEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
+    void focusInEvent(QFocusEvent *event) override;
+    void focusOutEvent(QFocusEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
 
     /**
      * Assign the time for the widget.
@@ -328,7 +342,6 @@ private:
     KTimeComboBoxPrivate *const d;
 
     Q_PRIVATE_SLOT(d, void selectTime(int index))
-    Q_PRIVATE_SLOT(d, void editTime(const QString &))
     Q_PRIVATE_SLOT(d, void enterTime(const QTime &))
     Q_PRIVATE_SLOT(d, void parseTime())
 
